@@ -1,19 +1,21 @@
 import tkinter as tk
+import platform
 from copy import deepcopy
 from tkinter import filedialog
 from tkinter import messagebox
 from tkcolorpicker import askcolor
 import numpy as np
 import matplotlib.pyplot as plt
-plt.rcParams["font.family"] = "Times New Roman"
 
 from matplotlib import get_backend
 
-if get_backend() == "module://ipykernel.pylab.backend_inline":
-    root = tk.Tk()
-    messagebox.showerror(title="Inline Plotting",
-                         message="Plots may not display with inline backend. \nPlots should still be able to be saved. \nPlease consider running code from command line in order to ensure full functionality.")
-    root.destroy()
+PLATFORM = platform.system()
+
+# if get_backend() == "module://ipykernel.pylab.backend_inline":
+    # root = tk.Tk()
+    # messagebox.showerror(title="Inline Plotting",
+                         # message="Plots may not display with inline backend. \nPlots should still be able to be saved. \nPlease consider running code from command line in order to ensure full functionality.")
+    # root.destroy()
 
 try:
     from .util import save_axis_data, save_plot_data, set_axis_data, set_plot_data
@@ -24,9 +26,25 @@ try:
 except ImportError:
     from plot_functions import plot_class
 try:
-    from .tkGUI import create_GUI
+    if PLATFORM == "Linux":
+        from .tkGUI_linux import create_GUI
+        plt.rcParams["font.family"] = 'DeJaVu Serif'
+    elif PLATFORM == "Darwin":
+        from .tkGUI_Mac import create_GUI
+        plt.rcParams["font.family"] = 'DeJaVu Serif'
+    else:
+        from .tkGUI import create_GUI
+        plt.rcParams["font.family"] = "Times New Roman"
 except ImportError:
-    from tkGUI import create_GUI
+    if PLATFORM == "Linux":
+        from tkGUI_linux import create_GUI
+        plt.rcParams["font.family"] = 'DeJaVu Serif'
+    elif PLATFORM == "Darwin":
+        from tkGUI_Mac import create_GUI
+        plt.rcParams["font.family"] = 'DeJaVu Serif'
+    else:
+        from tkGUI import create_GUI
+        plt.rcParams["font.family"] = "Times New Roman"
 
 # Defined Colours
 BG_BLUE = '#409fff'
@@ -48,44 +66,65 @@ class window(tk.Frame):
         
     def ebar_col_h(self):
         col = askcolor(self.ebar_color.get())[1]
-        self.ebar_color.set(col)
-        self.eb_col['bg'] = col
-        self.eb_col['activebackground'] = col
+        if col != None:
+            self.ebar_color.set(col)
+            if PLATFORM == "Darwin":
+                self.eb_col['fg'] = col
+            else:
+                self.eb_col['bg'] = col
+                self.eb_col['activebackground'] = col
+            
 
     def line_col_h(self):
         col = askcolor(self.line_color.get())[1]
         if col != None:
             self.line_color.set(col)
-            self.l_col['bg'] = col
-            self.l_col['activebackground'] = col
+            if PLATFORM == "Darwin":
+                self.l_col['fg'] = col
+            else:
+                self.l_col['bg'] = col
+                self.l_col['activebackground'] = col
 
     def me_col_h(self):
         col = askcolor(self.mark_ec.get())[1]
         if col != None:
             self.mark_ec.set(col)
-            self.m_ecol['bg'] = col
-            self.m_ecol['activebackground'] = col
+            if PLATFORM == "Darwin":
+                self.m_ecol['fg'] = col
+            else:
+                self.m_ecol['bg'] = col
+                self.m_ecol['activebackground'] = col
 
     def mf_col_h(self):
         col = askcolor(self.mark_fc.get())[1]
         if col != None:
             self.mark_fc.set(col)
-            self.m_fcol['bg'] = col
-            self.m_fcol['activebackground'] = col
+            if PLATFORM == "Darwin":
+                self.m_fcol['fg'] = col
+            else:
+                self.m_fcol['bg'] = col
+                self.m_fcol['activebackground'] = col
 
     def fe_col_h(self):
         col = askcolor(self.fill_ec.get())[1]
         if col != None:
             self.fill_ec.set(col)
-            self.f_ecol['bg'] = col
-            self.f_ecol['activebackground'] = col
+            if PLATFORM == "Darwin":
+                self.f_ecol['fg'] = col
+            else:
+                self.f_ecol['bg'] = col
+                self.f_ecol['activebackground'] = col
+            
 
     def ff_col_h(self):
         col = askcolor(self.fill_fc.get())[1]
         if col != None:
             self.fill_fc.set(col)
-            self.f_fcol['bg'] = col
-            self.f_fcol['activebackground'] = col
+            if PLATFORM == "Darwin":
+                self.f_fcol['fg'] = col
+            else:
+                self.f_fcol['bg'] = col
+                self.f_fcol['activebackground'] = col
 
     def clear_multi_choice(self):
         selected = self.selection_list.curselection()
@@ -470,12 +509,13 @@ class plotEditor():
             if labels == []:
                 self.labels = []
                 for i in range(len(x)):
-                    self.labels.append('')
+                    self.labels.append("Dataset-{}".format(i))
             else:
                 self.labels = []
                 for i in range(len(x)):
                     self.labels.append(labels[i].replace(' ', '-'))
 
+
         self.same_vectors = []
         self.same_vector_names = []
 
@@ -539,7 +579,10 @@ class plotEditor():
     
     def __add_input_str(self, var, val, index):
         if str(type(val)) == "<class 'str'>":
-            var.append(val.replace(' ','-'))
+            if val == '':
+                var.append("Dataset-{}".format(index))
+            else:
+                var.append(val.replace(' ','-'))
         else:
             var.append("Dataset-{}".format(index))
     
@@ -602,7 +645,10 @@ class plotEditor():
                         pass
                 except TypeError:
                     raise TypeError("All data inputs must have same type and shape")
-                self.__add_input_str(self.labels, labels[i], i)
+                try:
+                    self.__add_input_str(self.labels, labels[i], i)
+                except IndexError:
+                    self.__add_input_str(self.labels, '', i)
         elif len(x.shape) == 3:
             if x.shape[2] != 6:
                 raise ValueError("X-input must have size 6 in last dimension")
@@ -631,7 +677,10 @@ class plotEditor():
                     self.__add_input_np(self.dif_bot, x[i,:,5], i)
                 except IndexError:
                     self.dif_bot.append([])
-                self.__add_input_str(self.labels, labels[i], i)
+                try:
+                    self.__add_input_str(self.labels, labels[i], i)
+                except IndexError:
+                    self.__add_input_str(self.labels, '', i)
         else:
             raise ValueError("X-input shape cannot have more than 3 dimensions")
             
@@ -750,11 +799,14 @@ class plotEditor():
                 col_count = 0
         self.root = tk.Tk()
         self.root.title('Matplotlib Post Processor')
+        ico_file_dir = __file__.replace("pltEditorTool.py", "icon2.png")
+        self.root.iconphoto(False, tk.PhotoImage(file=ico_file_dir))
         #root.iconbitmap(bitmap='Main.ico')
         self.root.resizable(0, 0)
         self.root.protocol("WM_DELETE_WINDOW", self.callback)
         app = window(plot_data_Dict, master=self.root)
-        app['bg'] = BG_BLUE
+        if PLATFORM != "Darwin":
+            app['bg'] = BG_BLUE
         app.mainloop()
 
     def __check_input(self):
@@ -821,7 +873,7 @@ if __name__ == "__main__":
     print("Case 1: Ordinary List Style Input")
     
     plotEditor(x=x_data, y=y_data, x_err=x_err_data, y_err=y_err_data, 
-                fill=fill_data, fill_alt=fill_alt_data, labels=labels_data)
+                fill=fill_data, fill_alt=fill_alt_data)
     
     x_data = np.array(data.loc[:,'x.1'])
     y_data = np.array(data.loc[:,'y.1'])
@@ -833,7 +885,7 @@ if __name__ == "__main__":
     
     print("Case 2: Single Numpy Array Input")
     plotEditor(x=x_data, y=y_data, x_err=x_err_data, y_err=y_err_data, 
-                fill=fill_data, fill_alt=fill_alt_data, labels=labels_data)
+                fill=fill_data, fill_alt=fill_alt_data)
     
     x_data = np.array([np.array(data.loc[:,'x']), np.array(data.loc[:,'x.1'])]).transpose()
     y_data = np.array([np.array(data.loc[:,'y']), np.array(data.loc[:,'y.1'])]).transpose()
@@ -845,7 +897,7 @@ if __name__ == "__main__":
     
     print("Case 3: 2D Numpy Array Input")
     plotEditor(x=x_data, y=y_data, x_err=x_err_data, y_err=y_err_data, 
-                fill=fill_data, fill_alt=fill_alt_data, labels=labels_data)
+                fill=fill_data, fill_alt=fill_alt_data)
     
     input_data = np.zeros((2,101,6))
     input_data[0,:,0] = x_data[:,0]
@@ -861,7 +913,7 @@ if __name__ == "__main__":
     input_data[0,:,5] = fill_alt_data[:,0]
     input_data[1,:,5] = fill_alt_data[:,1]
     print("Case 4: 3D Numpy Array Input")
-    plotEditor(x=input_data, labels=labels_data)
+    plotEditor(x=input_data)
     
     print("Case 5: Pandas DataFrame Input")
-    plotEditor(x=data, labels=labels_data)    
+    plotEditor(x=data)    
